summaryrefslogtreecommitdiff
path: root/test/HTML5/Parser/EventStack.php
diff options
context:
space:
mode:
authorTechnosophos <[email protected]>2013-04-24 16:43:55 -0500
committerTechnosophos <[email protected]>2013-04-24 16:43:55 -0500
commit5bad030cd96865fd819ef477716decde07b04593 (patch)
tree76422e128701e4e3200f871e76aaeb1051b63a21 /test/HTML5/Parser/EventStack.php
parentb34490f3a1173ae2700b050868eb0301af49a22a (diff)
Moved to Elements::TEXT_RAW for Tokenizer.
Diffstat (limited to 'test/HTML5/Parser/EventStack.php')
-rw-r--r--test/HTML5/Parser/EventStack.php6
1 files changed, 4 insertions, 2 deletions
diff --git a/test/HTML5/Parser/EventStack.php b/test/HTML5/Parser/EventStack.php
index c9ac20e..1f56ea9 100644
--- a/test/HTML5/Parser/EventStack.php
+++ b/test/HTML5/Parser/EventStack.php
@@ -1,13 +1,15 @@
<?php
namespace HTML5\Parser;
+use HTML5\Elements;
+
/**
* This testing class gathers events from a parser and builds a stack of events.
* It is useful for checking the output of a tokenizer.
*
* IMPORTANT:
*
* The startTag event also kicks the parser into TEXTMODE_RAW when it encounters
* script or pre tags. This is to match the behavior required by the HTML5 spec,
* which says that the tree builder must tell the tokenizer when to switch states.
*/
@@ -49,7 +51,7 @@ class EventStack implements EventHandler {
$args = func_get_args();
$this->store('startTag', $args);
if ($name == 'pre' || $name == 'script') {
- return Tokenizer::TEXTMODE_RAW;
+ return Elements::TEXT_RAW;
}
}
@@ -1,13 +1,15 @@
* IMPORTANT:
*
- * The startTag event also kicks the parser into TEXTMODE_RAW when it encounters
+ * The startTag event also kicks the parser into TEXT_RAW when it encounters
* script or pre tags. This is to match the behavior required by the HTML5 spec,
* which says that the tree builder must tell the tokenizer when to switch states.